@@ -1,7 +1,9 @@
 mod tcp4;
 mod udp4;
 mod icmp4;
+mod vxlan;
 
 pub use tcp4::{TcpSeg, TcpFlow};
 pub use udp4::{UdpDgram, UdpFlow};
+pub use vxlan::{VxlanDgram, VxlanFlow};
 pub use icmp4::{IcmpDgram, IcmpFlow};
